/* drivers/video/tomtom/nec.c
 *
 * Specific functionality for the NEC screen. See:
 * http://www.nec-lcd.com/english/products/industries/nl2432hc22-22b.html
 *
 * Copyright (C) 2005 TomTom BV <http://www.tomtom.com/>
 * Author: Jeroen Taverne <jeroen.taverne@tomtom.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#include "lcdregs.h"
#include "nec.h"

#define MVAL_USED (0)
#define MVAL (0)

#define VFPD_240320 ((5-1)&0xff)
#define VBPD_240320 ((5-1)&0xff)
#define VSPW_240320 ((2-1)&0x3f)
#define HFPD_240320 ((8-1)&0xff)
#define HBPD_240320 ((16-1)&0x7f)
#define HSPW_240320 ((24-1)&0xff)
#define CLKVAL_TFT_240320 (6) // Maximum dotclock for NEC is 15 MHz

#define LCD_XSIZE_TFT_240320 (240)
#define LCD_YSIZE_TFT_240320 (320)
#define HOZVAL_TFT_240320    (LCD_XSIZE_TFT_240320-1)
#define LINEVAL_TFT_240320   (LCD_YSIZE_TFT_240320-1)

void NEC_Init(void)
{
	// Start display controller
	rLCDCON1 &= ~1;
	rTCONSEL = 2;
	rLCDCON1 = (CLKVAL_TFT_240320<<8)|(MVAL_USED<<7)|(3<<5)|(12<<1);
	rLCDCON2 = (VBPD_240320<<24)|(LINEVAL_TFT_240320<<14)|(VFPD_240320<<6)|(VSPW_240320);
	rLCDCON3 = (HBPD_240320<<19)|(HOZVAL_TFT_240320<<8)|(HFPD_240320);
	rLCDCON4 = (MVAL<<8)|(HSPW_240320);
	rLCDCON5 = (1<<11)|(1<<8)|(1<<4)|(1<<3)|(1<<2)|(1<<0);
	rLCDCON1 |= 1;
}

void NEC_Off(void)
{
	// Stop display controller
	rLCDCON1 = 0;
}

/* EOF */
